@@ -46,6 +46,9 @@ static gchar *contributors[] = {
 	"Chema Celorio",
 	"Damon Chaplin",
 	"Kevin Charter",
+	/* if your encoding allows it, use eacute (U00E9) for the first 
+	 * and the last 'e' in 'Chenede' */
+	N_("Erwann Chenede"),
 	/* CJK people please use (U5F35) (U570B) (U51A0) to replace
 	 * this name */
 	N_("Abel Cheung"),
@@ -85,6 +88,7 @@ static gchar *contributors[] = {
 	"John Fleck",
 	N_("Raul Perusquia Flores"),
 	"Lawrence Foard",
+	"Glynn Foster",
 	"Jeff Freedman",
 	"David Abilleira Freijeiro",
 	"Nat Friedman",
@@ -148,6 +152,7 @@ static gchar *contributors[] = {
 	"Birger Langkjer",
 	"Alexander Larsson",
 	"Guillaume Laurent",
+	"Ole Laursen",
 	"Michael Lausch",
 	"Will LaShell",
 	"Jens Lautenbacher",
@@ -196,6 +201,7 @@ static gchar *contributors[] = {
 	N_("Alexandre Muniz"),
 	/* Name in Hangeul is: Ub0a8 Uc131 Ud604 */
 	N_("Sung-Hyun Nam"),
+	"Deepa Natarajan",
 	"Karl Nelson",
 	"Asger Alstrup Nielsen",
 	"Seth Nickell",
@@ -301,12 +307,12 @@ static gchar *contributors[] = {
 	"David Winkler",
 	"Jeremy Wise",
 	"Roger Wolff",
+	"Frank Worsley",
 	"James Youngman",
 	"Orest Zborowski",
 	"Sascha Ziemann",
 	"Michael Zucchi",
 	"Jason van Zyl",
-	"Christian F.K. Schaller",
 	"",
 	""
 };
